<?php

use QUI\Database\Exception;
use QUI\ExceptionStack;
use QUI\Projects\Media\Utils as QUIMediaUtils;
use QUI\UserDownloads\Handler;

QUI::$Ajax->registerFunction(
    'package_quiqqer_user-downloads_ajax_backend_getList',
    /**
     * Get list of user downloads
     *
     * @param int|string $uid - User ID
     * @return array
     * @throws Exception
     * @throws \QUI\Exception
     * @throws ExceptionStack
     */
    function (int | string $uid) {
        $User = QUI::getUsers()->get($uid);
        $list = [];

        foreach (Handler::getDownloadEntriesByUser($User) as $DownloadEntry) {
            $downloadEntry = $DownloadEntry->toArray();
            $items = [];

            foreach ($DownloadEntry->getQuiqqerMediaUrls() as $quiqqerMediaUrl) {
                try {
                    $MediaItem = QUIMediaUtils::getMediaItemByUrl($quiqqerMediaUrl);
                } catch (\Exception) {
                    continue;
                }

                if ($MediaItem->isDeleted()) {
                    continue;
                }

                $items[] = [
                    'title' => method_exists($MediaItem, 'getTitle') ? $MediaItem->getTitle() : '',
                    'url' => $quiqqerMediaUrl
                ];
            }

            foreach ($DownloadEntry->getUrls() as $entry) {
                if (empty($entry['title'])) {
                    $entry['title'] = $entry['url'];
                }

                $items[] = $entry;
            }

            $downloadEntry['items'] = $items;

            $list[] = $downloadEntry;
        }

        return [
            'data' => $list,
            'page' => 1,
            'total' => count($list)
        ];
    },
    ['uid'],
    'Permission::checkAdminUser'
);
